public inbox for linux-ide@vger.kernel.org
 help / color / mirror / Atom feed
From: Damien Le Moal <damien.lemoal@opensource.wdc.com>
To: linux-ide@vger.kernel.org, linux-block@vger.kernel.org,
	Jens Axboe <axboe@kernel.dk>
Cc: "Maciej S . Szmigiero" <mail@maciej.szmigiero.name>,
	Hannes Reinecke <hare@suse.de>, Christoph Hellwig <hch@lst.de>,
	Niklas Cassel <niklas.cassel@wdc.com>
Subject: [PATCH v7 2/7] ata: libata: Introduce ata_ncq_supported()
Date: Tue,  3 Jan 2023 14:19:19 +0900	[thread overview]
Message-ID: <20230103051924.233796-3-damien.lemoal@opensource.wdc.com> (raw)
In-Reply-To: <20230103051924.233796-1-damien.lemoal@opensource.wdc.com>

Introduce the inline helper function ata_ncq_supported() to test if a
device supports NCQ commands. The function ata_ncq_enabled() is also
rewritten using this new helper function.

Signed-off-by: Damien Le Moal <damien.lemoal@opensource.wdc.com>
Reviewed-by: Hannes Reinecke <hare@suse.de>
Reviewed-by: Chaitanya Kulkarni <kch@nvidia.com>
Reviewed-by: Christoph Hellwig <hch@lst.de>
Reviewed-by: Johannes Thumshirn <johannes.thumshirn@wdc.com>
Reviewed-by: Niklas Cassel <niklas.cassel@wdc.com>
---
 include/linux/libata.h | 28 +++++++++++++++++++++-------
 1 file changed, 21 insertions(+), 7 deletions(-)

diff --git a/include/linux/libata.h b/include/linux/libata.h
index c9149ebe7423..650543afad32 100644
--- a/include/linux/libata.h
+++ b/include/linux/libata.h
@@ -1690,21 +1690,35 @@ extern struct ata_device *ata_dev_next(struct ata_device *dev,
 	     (dev) = ata_dev_next((dev), (link), ATA_DITER_##mode))
 
 /**
  *	ata_ncq_enabled - Test whether NCQ is enabled
  *	@dev: ATA device to test for
  *
  *	LOCKING:
  *	spin_lock_irqsave(host lock)
  *
  *	RETURNS:
- *	1 if NCQ is enabled for @dev, 0 otherwise.
+ *	true if @dev supports NCQ, false otherwise.
  */
-static inline int ata_ncq_enabled(struct ata_device *dev)
+static inline bool ata_ncq_supported(struct ata_device *dev)
 {
 	if (!IS_ENABLED(CONFIG_SATA_HOST))
-		return 0;
-	return (dev->flags & (ATA_DFLAG_PIO | ATA_DFLAG_NCQ_OFF |
-			      ATA_DFLAG_NCQ)) == ATA_DFLAG_NCQ;
+		return false;
+	return (dev->flags & (ATA_DFLAG_PIO | ATA_DFLAG_NCQ)) == ATA_DFLAG_NCQ;
+}
+
+/**
+ *	ata_ncq_enabled - Test whether NCQ is enabled
+ *	@dev: ATA device to test
+ *
+ *	LOCKING:
+ *	spin_lock_irqsave(host lock)
+ *
+ *	RETURNS:
+ *	true if NCQ is enabled for @dev, false otherwise.
+ */
+static inline bool ata_ncq_enabled(struct ata_device *dev)
+{
+	return ata_ncq_supported(dev) && !(dev->flags & ATA_DFLAG_NCQ_OFF);
 }
 
 static inline bool ata_fpdma_dsm_supported(struct ata_device *dev)
@@ -1690,21 +1690,35 @@ extern struct ata_device *ata_dev_next(struct ata_device *dev,
 
 /**
- *	ata_ncq_enabled - Test whether NCQ is enabled
- *	@dev: ATA device to test for
+ *	ata_ncq_supported - Test whether NCQ is supported
+ *	@dev: ATA device to test
  *
  *	LOCKING:
-- 
2.39.0


  parent reply	other threads:[~2023-01-03  5:22 UTC|newest]

Thread overview: 19+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-01-03  5:19 [PATCH v7 0/7] Improve libata support for FUA Damien Le Moal
2023-01-03  5:19 ` [PATCH v7 1/7] block: add a sanity check for non-write flush/fua bios Damien Le Moal
2023-01-03  8:05   ` Niklas Cassel
2023-01-03 12:46     ` Damien Le Moal
2023-01-03 13:02   ` Niklas Cassel
2023-01-04 14:23   ` Ming Lei
2023-01-05  3:54     ` Damien Le Moal
2023-01-03  5:19 ` Damien Le Moal [this message]
2023-01-03  5:19 ` [PATCH v7 3/7] ata: libata: Rename and cleanup ata_rwcmd_protocol() Damien Le Moal
2023-01-03  5:19 ` [PATCH v7 4/7] ata: libata: cleanup fua support detection Damien Le Moal
2023-01-03  5:19 ` [PATCH v7 5/7] ata: libata: Fix FUA handling in ata_build_rw_tf() Damien Le Moal
2023-01-03  5:19 ` [PATCH v7 6/7] ata: libata: blacklist FUA support for known buggy drives Damien Le Moal
2023-01-03  5:19 ` [PATCH v7 7/7] ata: libata: Enable fua support by default Damien Le Moal
2023-01-04 16:49 ` [PATCH v7 0/7] Improve libata support for FUA Tejun Heo
2023-01-05  3:43   ` Damien Le Moal
2023-01-05 18:15     ` Tejun Heo
2023-01-06  6:51       ` Damien Le Moal
2023-01-06 18:03         ` Tejun Heo
2023-01-10 13:23           ` Damien Le Moal

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20230103051924.233796-3-damien.lemoal@opensource.wdc.com \
    --to=damien.lemoal@opensource.wdc.com \
    --cc=axboe@kernel.dk \
    --cc=hare@suse.de \
    --cc=hch@lst.de \
    --cc=linux-block@vger.kernel.org \
    --cc=linux-ide@vger.kernel.org \
    --cc=mail@maciej.szmigiero.name \
    --cc=niklas.cassel@wdc.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox